@@ -6,7 +6,7 @@ from typing import Optional, Union
 
 from pls.config import icons
 from pls.enums.icon_type import IconType
-from pls.enums.node_type import NodeType, get_type_suffix
+from pls.enums.node_type import NodeType, get_type_color, get_type_icon, get_type_suffix
 from pls.globals import args
 from pls.models.base_node import BaseNode
 from pls.models.mixins.git import GitMixin
@@ -63,33 +63,34 @@ class Node(
         """the list of formatting rules to apply to the icons and text respectively"""
 
         fmt_rules = []
-        txt_fmt_rules = []
+        name_fmt_rules = []
 
         # font color
-        if not self.exists:
-            fmt_rules.append("red")  # only happens for broken symlinks
-        elif spec_color := self.spec_attr("color"):
+        if spec_color := self.spec_attr("color"):
             fmt_rules.append(str(spec_color))
-        elif self.node_type == NodeType.DIR:
-            fmt_rules.append("cyan")
+        else:
+            node_type = self.node_type if self.exists else NodeType.BROKEN
+            color = get_type_color(node_type)
+            if color is not None:
+                fmt_rules.append(color)
 
         imp_fmt_rules, imp_txt_fmt_rules = self.importance_format_rules
         if imp_fmt_rules:
             fmt_rules.extend(imp_fmt_rules)
         if imp_txt_fmt_rules:
-            txt_fmt_rules.extend(imp_txt_fmt_rules)
+            name_fmt_rules.extend(imp_txt_fmt_rules)
 
         git_fmt_rules, git_txt_fmt_rules = self.git_format_rules
         if git_fmt_rules:
             fmt_rules.extend(git_fmt_rules)
         if git_txt_fmt_rules:
-            txt_fmt_rules.extend(git_txt_fmt_rules)
+            name_fmt_rules.extend(git_txt_fmt_rules)
 
         if self.name == ".pls.yml":
-            txt_fmt_rules.append("italic")
+            name_fmt_rules.append("italic")
 
-        txt_fmt_rules.extend(fmt_rules)
-        return fmt_rules, txt_fmt_rules
+        name_fmt_rules.extend(fmt_rules)
+        return fmt_rules, name_fmt_rules
 
     @staticmethod
     def _get_format_pair(format_rules: list[str]) -> tuple[str, str]:
@@ -109,14 +110,14 @@ class Node(
         return left, right
 
     @cached_property
-    def text_format_pair(self) -> tuple[str, str]:
+    def name_format_pair(self) -> tuple[str, str]:
         """the opening and closing tags of Rich console formatting markup for text"""
 
-        _, txt_fmt_rules = self.format_rules
-        return self._get_format_pair(txt_fmt_rules)
+        _, name_fmt_rules = self.format_rules
+        return self._get_format_pair(name_fmt_rules)
 
     @cached_property
-    def icon_format_pair(self) -> tuple[str, str]:
+    def format_pair(self) -> tuple[str, str]:
         """the opening and closing tags of Rich console formatting markup for icons"""
 
         fmt_rules, _ = self.format_rules
@@ -153,7 +154,7 @@ class Node(
             name = f"{name}{self.formatted_suffix}"
 
         # Apply format pair.
-        left, right = self.text_format_pair
+        left, right = self.name_format_pair
         name = f"{left}{name}{right}"
 
         if args.args.align and not self.is_pseudo:
@@ -181,15 +182,15 @@ class Node(
             icon_index = icons.nerd_icons
 
         if spec_icon := self.spec_attr("icon"):
-            icon = icon_index.get(str(spec_icon))
-        elif self.node_type == NodeType.DIR:
-            icon = icon_index.get("folder")
+            icon = icon_index.get(spec_icon)
+        elif icon_name := get_type_icon(self.node_type):
+            icon = icon_index.get(icon_name)
         else:
             icon = None
 
         if icon:
             # Apply format pair.
-            left, right = self.icon_format_pair
+            left, right = self.format_pair
             icon = f"{left}{icon}{right}"
         else:
             icon = ""
@@ -199,7 +200,7 @@ class Node(
     def formatted_type_char(self) -> str:
         """the type character associated with the type of the node"""
 
-        left, right = self.text_format_pair
+        left, right = self.format_pair
         return f"{left}{self.type_char}{right}"
 
     @cached_property
